@@ -1,6 +1,6 @@
 
 /**************************************************************************
- * Copyright (C) 2007 Ruben Pollan Bella <meskio@amedias.org>             *
+ * Copyright (C) 2007-2008 Ruben Pollan Bella <meskio@amedias.org>        *
  *                                                                        *
  *  This file is part of TuDu.                                            *
  *                                                                        *
@@ -114,33 +114,136 @@ int Date::daysLeft()
 	return daysleft;
 }
 
+Date Date::operator-(int days)
+{
+	Date d(_day, _month, _year);
+
+	d._day -= days;
+	while (d._day <= 0)
+	{
+		d._month--;
+		if (d._month == 0)
+		{
+			d._month = 12;
+			d._year--;
+		}
+
+		switch (d._month)
+		{
+			case 1:
+			case 3:
+			case 5:
+			case 7:
+			case 8:
+			case 10:
+			case 12:
+				d._day += 31;
+				break;
+			case 4:
+			case 6:
+			case 9:
+			case 11:
+				d._day += 30;
+				break;
+			case 2:
+				/* if leap year */
+				if ((d._year % 4 == 0) && !((d._year % 100 == 0) && (d._year % 1000 != 0)))
+				{
+					d._day += 29;
+				}
+				else
+				{
+					d._day += 28;
+				}
+				break;
+		}
+	}
+
+	return d;
+}
+
+Date Date::operator+(int days)
+{
+	Date d(_day, _month, _year);
+	bool day_valid = false;
+
+	d._day += days;
+	do {
+		switch (d._month)
+		{
+			case 1:
+			case 3:
+			case 5:
+			case 7:
+			case 8:
+			case 10:
+			case 12:
+				if (d._day <= 31) day_valid = true;
+				else d._day -= 31;
+				break;
+			case 4:
+			case 6:
+			case 9:
+			case 11:
+				if (d._day <= 30) day_valid = true;
+				else d._day -= 30;
+				break;
+			case 2:
+				/* if leap year */
+				if ((d._year % 4 == 0) && !((d._year % 100 == 0) && (d._year % 1000 != 0)))
+				{
+					if (d._day <= 29) day_valid = true;
+					else d._day -= 29;
+				}
+				else
+				{
+					if (d._day <= 28) day_valid = true;
+					else d._day -= 28;
+				}
+				break;
+		}
+
+		if (!day_valid)
+		{
+			d._month++;
+			if (d._month == 13)
+			{
+				d._month = 1;
+				d._year++;
+			}
+		}
+	} while (!day_valid);
+
+	return d;
+}
+
 bool Date::operator<(Date d)
 {
-	if (d._year < _year)
-		return false;
-	else if (d._year > _year)
+	if (_year < d._year)
 		return true;
-	else if (d._month < _month)
+	else if (_year > d._year)
 		return false;
-	else if (d._month > _month)
+	else if (_month < d._month)
 		return true;
-	else if (d._day < _day)
+	else if (_month > d._month)
 		return false;
+	else if (_day < d._day)
+		return true;
 	else
-		return true;
+		return false;
 }
 
 bool Date::operator>(Date d)
 {
-	if (d._year > _year)
+	if (_year > d._year)
 		return true;
-	else if (d._year < _year)
+	else if (_year < d._year)
 		return false;
-	else if (d._month > _month)
+	else if (_month > d._month)
 		return true;
-	else if (d._month < _month)
+	else if (_month < d._month)
 		return false;
-	else if (d._day > _day)
+	else if (_day > d._day)
 		return true;
 	else
 		return false;
@@ -157,3 +260,15 @@ bool Date::operator!=(Date d)
 	else
 		return false;
 }
+
+bool Date::operator==(Date d)
+{
+	if (d._year !=  _year)
+		return false;
+	else if (d._month !=  _month)
+		return false;
+	else if (d._day != _day)
+		return false;
+	else
+		return true;
+}
